<?php
namespace Studip\Dockerized\Commands;

use Studip\Dockerized\Config;
use Studip\Dockerized\SupportedPHPVersions;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;

final class Init extends Command
{
    protected function configure()
    {
        $this->setName('init');
        $this->setDescription('Inits studip-dockerized');

        $this->addOption('force', 'f', InputOption::VALUE_NONE, 'Force creation of config file');
    }

    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $io = new SymfonyStyle($input, $output);

        if (file_exists(CONFIG_FILE) && !$input->getOption('force')) {
            $io->error('Config file already exists.');
            return Command::FAILURE;
        }

        $config = Config::create(CONFIG_FILE, false);
        $config->set('php', array_combine(
            SupportedPHPVersions::getDefaultVersions(),
            array_map(
                fn(string $version): array => SupportedPHPVersions::mapPort($version),
                SupportedPHPVersions::getDefaultVersions()
            )
        ));
        $config->store();

        $io->success('Config file has been created');

        return Command::SUCCESS;
    }
}
