<?php /** @noinspection PhpExpressionResultUnusedInspection */

namespace Studip\Dockerized\Commands\Keys;

use Studip\Dockerized\Traits\GetCompiledPath;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;
use Symfony\Component\Process\Process;

final class Create extends Command
{
    use GetCompiledPath;

    protected function configure()
    {
        $this->setName('keys:create');
        $this->setDescription('Creates necessary keys for ssl');
    }

    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $io = new SymfonyStyle($input, $output);

        $process = new Process([
            'openssl', 'req',
            '-x509',
            '-out', $this->getCompiledPath('ssl.crt'),
            '-keyout', $this->getCompiledPath('ssl.key'),
            '-newkey', 'rsa:2048',
            '-nodes',
            '-sha256',
            '-days', '365',
            '-subj', '/CN=localhost',
            '-extensions', 'EXT',
            '-config', realpath(__DIR__ . '/../../../config/openssl-cert-request'),
        ]);
        $process->run();

        if (!$process->isSuccessful()) {
            $io->error(['Could not create keys', $process->getErrorOutput()]);
            return Command::FAILURE;
        }

        $io->success('Keys created successfully');

        return Command::SUCCESS;
    }
}
