<?php
namespace Studip\Dockerized\Commands\PHP;

use Studip\Dockerized\Config;
use Studip\Dockerized\SupportedPHPVersions;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;

final class Disable extends Command
{
    protected function configure()
    {
        $this->setName('php:disable');
        $this->setDescription('Disable PHP version (needs recompile)');
        $this->addArgument(
            'version',
            InputArgument::REQUIRED | InputArgument::IS_ARRAY,
            'PHP version(s) that should be disabled',
            null,
            SupportedPHPVersions::getVersions()
        );
    }

    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $config = Config::getInstance();
        $io = new SymfonyStyle($input, $output);

        $disabled = 0;
        foreach ($input->getArgument('version') as $version) {
            if (!isset($config->get('php')[$version])) {
                $io->error("PHP version {$version} is not enabled");
                continue;
            }

            $php = $config->get('php');
            unset($php[$version]);
            $config->set('php', $php);

            $io->success("PHP version {$version} has been disabled");
            $disabled += 1;
        }

        if ($disabled === 0) {
            return Command::FAILURE;
        }

        $config->store();

        return Command::SUCCESS;
    }
}
