<?php
namespace Studip\Dockerized\Commands\PHP;

use Studip\Dockerized\Config;
use Studip\Dockerized\SupportedPHPVersions;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;

final class Enable extends Command
{
    protected function configure()
    {
        $this->setName('php:enable');
        $this->setDescription('Enable PHP version (needs recompile)');
        $this->addArgument(
            'version',
            InputArgument::REQUIRED | InputArgument::IS_ARRAY,
            'PHP version(s) that should be enabled',
            null,
            SupportedPHPVersions::getVersions()
        );
    }

    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $config = Config::getInstance();
        $io = new SymfonyStyle($input, $output);

        $enabled = 0;
        foreach ($input->getArgument('version') as $version) {
            if (isset($config->get('php')[$version])) {
                $io->error("PHP version {$version} is already enabled");
                continue;
            }

            $port = SupportedPHPVersions::mapPort($version);

            $php = $config->get('php');
            $php[$version] = $port;
            $config->set('php', $php);

            $io->success("PHP version {$version} has been enabled on ports {$port[0]} and {$port[1]}");
            $enabled += 1;
        }

        if ($enabled === 0) {
            return Command::FAILURE;
        }

        $config->store();

        return Command::SUCCESS;
    }
}
