<?php
namespace Studip\Dockerized\Commands\PHP;

use Studip\Dockerized\Config;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;

final class Port extends Command
{
    protected function configure()
    {
        $this->setName('php:port');
        $this->setDescription('Change port for PHP version (needs recompile)');
        $this->addArgument(
            'version',
            InputArgument::REQUIRED,
            'PHP version',
            null,
            array_keys(Config::getInstance()->get('php'))
        );
        $this->addArgument(
            'port',
            InputArgument::REQUIRED,
            'Port to use'
        );

        $this->addArgument(
            'ssl-port',
            InputArgument::REQUIRED,
            'SSL-Port to use'
        );
    }

    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $version = $input->getArgument('version');
        $port = (int) $input->getArgument('port');
        $sslPort = (int) $input->getArgument('ssl-port');

        $config = Config::getInstance();
        $io = new SymfonyStyle($input, $output);

        if (!isset($config->get('php')[$version])) {
            $io->error("PHP version {$version} is not enabled");
            return Command::FAILURE;
        }

        $php = $config->get('php');
        $php[$version] = [$port, $sslPort];
        $config->set('php', $php);
        $config->store();

        $io->success("Ports of PHP version {$version} were changed to {$port} / {$sslPort}");

        return Command::SUCCESS;
    }
}
