<?php
namespace Studip\Dockerized\Commands\PHP;

use Studip\Dockerized\Config;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;

final class SetDefault extends Command
{
    protected function configure()
    {
        $this->setName('php:default');
        $this->setDescription('Set PHP version as default');
        $this->addArgument(
            'version',
            InputArgument::REQUIRED,
            'PHP version(s) that should be disabled',
            null,
            array_keys(Config::getInstance()->get('php')) + ['none']
        );
    }

    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $config = Config::getInstance();
        $io = new SymfonyStyle($input, $output);

        $version = $input->getArgument('version');

        if (
            $version !== 'none'
            && !array_key_exists($version, $config->get('php'))
        ) {
            $io->error("PHP version {$version} is not enabled");
            return Command::FAILURE;
        }

        if ($version === $config->get('default')) {
            return Command::SUCCESS;
        }

        if ($version === 'none') {
            $config->delete('default');
            $config->store();

            $io->success('Default PHP version has been removed');
        } else {
            $config->set('default', $version);
            $config->store();

            $io->success("PHP version {$version} was set as default");
        }

        return Command::SUCCESS;
    }
}
