<?php

namespace Studip\Dockerized\Commands\Sites;

use Exception;
use Studip\Dockerized\Config;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;

final class Remove extends Command
{
    protected function configure()
    {
        $this->setName('site:remove');
        $this->setDescription('Remove a site (needs recompile)');
        $this->addArgument('webpath', InputArgument::REQUIRED, 'The web path');
    }

    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $io = new SymfonyStyle($input, $output);

        $webPath = $input->getArgument('webpath');

        $config = Config::getInstance();
        $sites = $config->get('sites') ?? [];

        if ($webPath === 'sites') {
            throw new Exception("Web path 'sites' is prohibited");
        }

        if (!array_key_exists($webPath, $sites)) {
            $io->error("The site '{$webPath}' does not exist.");
            return Command::FAILURE;
        }

        unset($sites[$webPath]);
        if (count($sites) > 0) {
            ksort($sites);
            $config->set('sites', $sites);
        } else {
            $config->delete('sites');
        }

        $config->store();

        $io->success("Site '{$webPath}' has been removed.");

        return Command::SUCCESS;
    }
}