<?php
namespace Studip\Dockerized;

final class Config
{
    private static ?Config $instance = null;

    public static function load(string $filename): void
    {
        self::$instance = self::create($filename);
    }

    public static function create(string $filename, bool $initialReset = true): Config
    {
        return new self($filename, $initialReset);
    }

    public static function getInstance(): Config
    {
        if (!isset(self::$instance)) {
            throw new \Exception('Config has not been loaded');
        }
        return self::$instance;
    }

    private array $data = [];
    private string $filename;

    private function __construct(string $filename, bool $initialReset = true)
    {
        $this->filename = $filename;

        if ($initialReset) {
            $this->reset();
        }
    }

    public function get(string $key): mixed
    {
        return $this->data[$key] ?? null;
    }

    public function set(string $key, mixed $value): Config
    {
        $this->data[$key] = $value;

        return $this;
    }

    public function has(string $key): bool
    {
        return array_key_exists($key, $this->data);
    }

    public function delete(string $key): Config
    {
        unset($this->data[$key]);

        return $this;
    }

    public function dump(): string
    {
        return json_encode($this->data, JSON_PRETTY_PRINT);
    }

    public function reset(): Config
    {
        if (!file_exists($this->filename)) {
            throw new \Exception("Config file '{$this->filename}' does not exist");
        }

        if (!is_readable($this->filename)) {
            throw new \Exception("Config file '{$this->filename}' is not readable");
        }

        $this->data = json_decode(file_get_contents($this->filename), true);

        return $this;
    }

    public function store(): Config
    {
        if (file_exists($this->filename) && !is_writable($this->filename)) {
            throw new \Exception("Config file '{$this->filename}' is not writable");
        }

        file_put_contents($this->filename, $this->dump());

        return $this;
    }
}
