<?php
namespace Studip\Dockerized;

use Closure;
use Exception;

abstract class ConfigurationCreator
{
    private array $configuration = [];
    private array $hooks = [];

    public function hook(string $type, Closure $hook): void
    {
        if (!isset($this->hooks[$type])) {
            $this->hooks[$type] = [];
        }
        $this->hooks[$type][] = $hook;
    }

    public function addConfiguration(string $type, mixed $data, string $key = null): void
    {
        if (!isset($this->configuration[$type])) {
            $this->configuration[$type] = [];
        }
        if (isset($key)) {
            $this->configuration[$type][$key] = $this->applyHooks($type, $data);
        } else {
            $this->configuration[$type][] = $this->applyHooks($type, $data);
        }
    }

    protected function getConfiguration(?string $type = null, mixed $default = null): mixed
    {
        if (func_num_args() === 0 || $type === null) {
            return $this->configuration;
        }

        return $this->configuration[$type] ?? $default;
    }

    protected function applyHooks(string $type, mixed $config): mixed
    {
        foreach ($this->hooks[$type] ?? [] as $hook) {
            $config = $hook($config);
        }
        return $config;
    }
}
