<?php
namespace Studip\Dockerized\Creators;

use Studip\Dockerized\ConfigurationCreator;
use Symfony\Component\Yaml\Yaml;

final class DockerComposeConfiguration extends ConfigurationCreator
{
    private string $cwd;

    public function __construct(string $cwd, string $name = '')
    {
        $this->cwd = $cwd;

        if ($name) {
            $this->addConfiguration('name', $name);
        }
    }

    public function addService(string $service, ?string $image, array $config = []): void
    {
        $this->addConfiguration('services', array_merge(
            isset($image) ? ['image' => $image] : [],
            $config
        ), $service);
    }

    public function addServiceVolume(string $service, string $source, string $target, string $modifier = ''): void
    {
        $config = $this->getConfiguration('services', []);

        if (!array_key_exists($service, $config)) {
            throw new \Exception('Service "' . $service . '" does not exist');
        }

        if (!isset($config[$service]['volumes'])) {
            $config[$service]['volumes'] = [];
        }
        $config[$service]['volumes'][] = implode(':', array_filter([
            $source,
            $target,
            $modifier,
        ]));

        $this->addConfiguration('services', $config[$service], $service);
    }

    public function addNetwork(string $network, array $config): void
    {
        $this->addConfiguration('networks', $config, $network);
    }

    public function addVolume(string $volume): void
    {
        $config = $this->getConfiguration('volumes', []);

        if (array_key_exists($volume, $config)) {
            throw new \Exception('Volume "' . $volume . '" already exists');
        }

        $this->addConfiguration('volumes', ['name' => $volume], $volume);
    }

    public function dump(): string
    {
        return Yaml::dump($this->getConfiguration(), 4);
    }
}
