<?php
namespace Studip\Dockerized\Creators;

use RomanPitak\Nginx\Config\Scope;
use Studip\Dockerized\ConfigurationCreator;

final class NginxConfiguration extends ConfigurationCreator
{
    public function addLocation(string $location, array $config, string $modifier = '^~')
    {
        $this->addConfiguration('location', [
            'location' => '/' . ltrim($location, '/'),
            'modifier' => $modifier,
            'config'   => $config,
        ]);
    }

    public function addServer(array $config)
    {


        $this->addConfiguration('server', [
            'config' => $config,
        ]);
    }

    public function addUpstream(string $upstream, array $config)
    {
        $this->addConfiguration('upstream', [
            'upstream' => $upstream,
            'config' => $config,
        ]);
    }

    public function dump(): string
    {
        $tempName = tempnam(sys_get_temp_dir(), 'nginx');
        file_put_contents($tempName, implode("\n", [
            ...array_map(
                fn($upstream) => $this->write(
                    "upstream {$upstream['upstream']}",
                    $upstream['config']
                ),
                $this->getConfiguration('upstream', [])
            ),
            ...array_map(
                fn($server) => $this->write(
                    'server',
                    $server['config']
                ),
                $this->getConfiguration('server', [])
            ),
            ...array_map(
                fn($location) => $this->write(
                    "location {$location['modifier']} {$location['location']}",
                    $location['config']
                ),
                $this->getConfiguration('location', [])
            ),
        ]));
        $result = (string) Scope::fromFile($tempName);
        unlink($tempName);

        return $result;
    }

    private function write(string $index, array $content): string
    {
        return sprintf(
            '%s { %s }',
            $index,
            implode("\n", array_map(
                fn (string $what): string => rtrim(trim($what), ';') . ';',
                $content
            ))
        );
    }
}
