<?php
namespace Studip\Dockerized;

use Studip\Dockerized\Traits\GetCompiledPath;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Process\Process;

abstract class DockerComposeCommand extends Command
{
    use GetCompiledPath;

    abstract protected function getDockerComposeCommand(): array;

    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $process = $this->createDockerComposeCommand($this->getDockerComposeCommand());
        $this->streamProcess($process, $output);
        return $process->isSuccessful() ? Command::SUCCESS : Command::FAILURE;
    }

    protected function createDockerComposeCommand(array $command): Process
    {
        $process = new Process([
            'docker', 'compose',
            '-f', self::GetCompiledPath() . '/docker-compose.yml',
            ...$command,
        ]);
        $process->setTimeout(null);
        return $process;

    }

    protected function streamProcess(Process $process, OutputInterface $output): void
    {
        $process->setTty(true);
        $process->mustRun(function ($type, $buffer) use ($output) {
            if (Process::OUT === $type) {
                $output->write($buffer);
            } else {
                $output->write('<error>' . $buffer . '</error>');
            }
        });
    }

    protected function isDockerRunning(): bool
    {
        $process = $this->createDockerComposeCommand(['ps']);
        $process->run();

        if (!$process->isSuccessful()) {
            return false;
        }

        $output = trim($process->getOutput());

        return count(explode("\n", $output)) > 1;
    }
}