<?php
require_once __DIR__ . '/LogParser.php';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (!empty($_POST['empty-log'])) {
        file_put_contents(__DIR__ . '/../logs/php/error.log', '');
    }

    header('Location: ' . $_SERVER['REQUEST_URI']);
    exit;
}

$config = json_decode(file_get_contents(__DIR__ . '/../studip-dockerized-config.json'), true);
$versions = $config['php'];
ksort($versions);

$log = new LogParser(__DIR__ . '/../logs/php/error.log');
?>
<!doctype html>
<html lang="en">
<head>
    <link href="assets/style.css" type="text/css" rel="stylesheet">
    <script src="assets/script.js"></script>
    <title>Available sites</title>
</head>
<body>
    <nav class="tabs">
        <a href="#sites" class="active">
            Sites
        </a>
        <a href="#logs">
            Logs
        </a>

        <a href="http://localhost:8044?username=root" target="_blank" class="right">
            Adminer
        </a>
        <a href="http://localhost:8045" target="_blank">
            Dozzle
        </a>
    </nav>

    <section id="sites">
    <?php if (empty($config['sites'])): ?>
        No sites defined
    <?php else: ?>
        <table>
            <thead>
                <tr>
                    <th>Name</th>
                <? foreach (array_keys($versions) as $version): ?>
                    <th colspan="2" style="text-align: center">
                        <?= htmlentities($version) ?>
                    </th>
                <? endforeach; ?>
                </tr>
            </thead>
            <tbody>
            <?php foreach ($config['sites'] ?? [] as $path => $definition): ?>
                <tr>
                    <td>
                    <?php if (!empty($config['default'])): ?>
                        <a href="https://localhost/<?= htmlentities($path) ?>">
                            <?= htmlentities($path) ?>
                        </a>
                    <?php else: ?>
                        <?= htmlentities($path) ?>
                    <?php endif; ?>
                    </td>
                    <?php foreach ($versions as $version => [$port, $sslPort]): ?>
                        <td>
                            <a href="https://localhost:<?= $sslPort ?>/<?= htmlentities($path) ?>">
                                https
                            </a>
                        </td>
                        <td>
                            <a href="http://localhost:<?= $port ?>/<?= htmlentities($path) ?>">
                                http
                            </a>
                        </td>
                    <?php endforeach; ?>
                </tr>
            <?php endforeach; ?>
            </tbody>
        </table>
    <?php endif; ?>

    </section>

    <section id="logs">
        <nav id="logs-nav">
            <form action="<?= $_SERVER['REQUEST_URI'] ?>"
                  method="post"
                  onsubmit="return confirm('Do you really want to empty the logs?');"
            >
                <button type="submit" name="empty-log" value="1" class="as-link">
                    🗑️
                </button>
            </form>
        </nav>
    <?php if ($log->hasData()): ?>
        <ul>
        <?php foreach ($log->entries() as $entry): ?>
            <li>
                <?= nl2br(htmlentities($entry)) ?>
            </li>
        <?php endforeach; ?>
        </ul>
    <?php endif; ?>
    </section>
</body>
</html>
